@@ -22,9 +22,9 @@ else :
         )
 
     from dstk.pytorch._utils import (check_tensor, check_tensor_dict, detach,
-                                     collate_zeros_padding, make_mask)
+                                     collate_zeros_padding, make_mask,
+                                     is_dist_avail_and_initialized)
     from dstk.pytorch._utils_distrib import (get_rank,
-                                             is_dist_avail_and_initialized,
                                              is_main_process, save_on_master,
                                              init_distributed,
                                              auto_init_distributed)
@@ -32,8 +32,7 @@ else :
                                         FitState, FitControl, PrintCallback,
                                         ProgressBarCallback, Backup,
                                         LRSchedulerCallback,
-                                        EarlyStoppingCallback, Supervision,
-                                        DEFAULT_CALLBACKS)
+                                        EarlyStoppingCallback, Supervision)
     from dstk.pytorch._random_search import RandomizedSearchOnline
     from dstk.pytorch._swa import StochasticWeightAveraging, cut_dataset
     from dstk.pytorch._classifier import BaseClassifier, BaseClassifierOnline
@@ -54,7 +53,6 @@ else :
         'EarlyStoppingCallback',
         'LRSchedulerCallback',
         'Supervision',
-        'DEFAULT_CALLBACKS',
         'StochasticWeightAveraging',
         'cut_dataset',
         'check_tensor',
