@@ -9,8 +9,7 @@ Created on Sat Oct 22 14:50:47 2022
 """
 
 import os
-from typing import Optional, Dict, Any, Callable
-from itertools import product
+from typing import Optional, Dict, Any
 from warnings import warn
 
 import torch
@@ -21,9 +20,6 @@ from torch.utils.data import Dataset, DataLoader
 from torch.utils.data.distributed import DistributedSampler
 
 from dstk.pytorch._utils import is_dist_avail_and_initialized
-from dstk.pytorch._base import BaseEnvironnement
-from dstk.pytorch._classifier import BaseClassifier, BaseClassifierOnline
-from dstk.pytorch._regressor import BaseRegressor, BaseRegressorOnline
 
 
 def is_main_process():
@@ -88,83 +84,6 @@ def init_distributed(dist_url: str = "env://", backend: str = "nccl"):
     return local_rank
 
 
-def _overload_distributed_data_parallel(
-    model: Module,
-    master_class: Optional[Callable] = None
-):
-    r"""
-    Fonction qui vien surchargé la classe
-    torch.nn.parallel.DistributedDataParallel afin de s'interfacer avec
-    les classes DSTK. Pour connaitre les arguements de cette classe ce
-    référer à la doc PyTorch.
-
-    Parameters
-    ----------
-    model: Module
-        Modèle PyTorch vania ou hérité des classes DSTK.
-    master_class: Optional[Callable]
-        Classe mère que l'on souhaite faire hérité. Si cette variable est
-        a None une recherce de maching sera exécutée sur les classes types
-        de base de DSTK.
-    """
-    def gen_class(module):
-        class DistributedDataParallel(DDP, module):
-            def __init__(
-                self,
-                module,
-                device_ids=None,
-                output_device=None,
-                dim=0,
-                broadcast_buffers=True,
-                process_group=None,
-                bucket_cap_mb=25,
-                find_unused_parameters=False,
-                check_reduction=False,
-                gradient_as_bucket_view=False,
-                static_graph=False,
-            ):
-                super().__init__(
-                    module=module,
-                    device_ids=device_ids,
-                    output_device=output_device,
-                    dim=dim,
-                    broadcast_buffers=broadcast_buffers,
-                    process_group=process_group,
-                    bucket_cap_mb=bucket_cap_mb,
-                    find_unused_parameters=find_unused_parameters,
-                    check_reduction=check_reduction,
-                    gradient_as_bucket_view=gradient_as_bucket_view,
-                    static_graph=static_graph,
-                )
-        return DistributedDataParallel
-
-    if not master_class is None:
-        return gen_class(master_class)
-
-    mother_model = model.__class__.__bases__
-    dstk_module = [BaseEnvironnement, BaseClassifier, BaseClassifierOnline,
-                   BaseRegressor, BaseRegressorOnline]
-    match = list(
-        filter(
-            lambda x: x[0] == x[1],
-            product(mother_model, dstk_module)
-        )
-    )
-    if len(match) == 0:
-        return DDP
-    elif len(match) == 1:
-        return gen_class(match[0][1])
-    else:
-        match = list(filter(lambda x: x[0] != BaseEnvironnement, match))
-        if len(match) == 1:
-            return gen_class(match[0][1])
-        else:
-            raise AttributeError(
-                "L'héritage du module PyTorch est incompatible avec le "
-                "système d'hérithage de DSTK."
-            )
-
-
 def overload_distributed_data_parallel(model: Module):
     r"""
     Fonction qui vien surchargé la classe
@@ -205,11 +124,22 @@ def overload_distributed_data_parallel(model: Module):
                 gradient_as_bucket_view=gradient_as_bucket_view,
                 static_graph=static_graph,
             )
+
     attr = list(filter(lambda x: not x.startswith('__'), dir(model)))
     attr_ddp = list(filter(lambda x: not x.startswith('__'), dir(DDP)))
     for ii in attr:
         if not ii in attr_ddp:
             setattr(DistributedDataParallel, ii, getattr(model, ii))
+        else:
+            warn(
+                f"L'attribut {ii} est commun à la classe "
+                f"{model.__class__.__name__} et à la classe DPP de PyTorch. "
+                "La prioriété est donnée a DDP et peut ne pas avoir "
+                "d'impacte sur la suite de l'entrainement. Dans le cas "
+                "contraire changer le nom de l'attribut pour ne pas "
+                "rentrer en conflict avec DDP."
+            )
+
     return DistributedDataParallel
 
 
@@ -221,8 +151,7 @@ def auto_init_distributed(
     kwargs_eval_dataloader: Optional[Dict[str, Any]] = None,
     dist_url: str = "env://",
     backend: str = "nccl",
-    seed: int = 42,
-    master_class: Optional[Callable] = None
+    seed: int = 42
 ):
     r"""
     
@@ -252,10 +181,6 @@ def auto_init_distributed(
         Seed à destination du DistributedSampler afin de garantir que tous
         les processes aient la même seed pour le mélange (sinon les processes
         pourraient avoir des observations commune dans une eproch).
-    master_class: Optional[Callable]
-        Classe mère que l'on souhaite faire hérité. Si cette variable est
-        a None une recherce de maching sera exécutée sur les classes de types
-        de base de DSTK.
 
     Notes
     -----
@@ -287,10 +212,6 @@ def auto_init_distributed(
 
     model = model.cuda()
     model = SyncBatchNorm.convert_sync_batchnorm(model)
-    # model = overload_distributed_data_parallel(model, master_class)(
-    #     module=model,
-    #     device_ids=[local_rank]
-    # )
     model = overload_distributed_data_parallel(model)(
         module=model,
         device_ids=[local_rank]
